@@ -18,7 +18,7 @@ from pkg_resources import resource_filename
 
 from ctapipe.io import EventSource, DataLevel
 from ctapipe.core import Container, Field, Provenance
-from ctapipe.core.traits import Bool
+from ctapipe.core.traits import Bool, CaselessStrEnum
 from ctapipe.coordinates import CameraFrame
 
 from ctapipe.containers import (
@@ -68,14 +68,6 @@ MAGIC_TO_CTA_EVENT_TYPE = {
     PEDESTAL_TRIGGER_PATTERN: EventType.SKY_PEDESTAL,
 }
 
-OPTICS = OpticsDescription(
-    'MAGIC',
-    num_mirrors=1,
-    equivalent_focal_length=u.Quantity(17.*1.0713, u.m),
-    mirror_area=u.Quantity(239.0, u.m**2),
-    num_mirror_tiles=964,
-)
-
 
 def load_camera_geometry():
     ''' Load camera geometry from bundled resources of this repo '''
@@ -130,8 +122,14 @@ class MAGICEventSource(EventSource):
     ).tag(config=True)
 
     use_pedestals = Bool(
-           default_value=False,
-           help='Extract pedestal events instead of cosmic events.'
+        default_value=False,
+        help='Extract pedestal events instead of cosmic events.'
+    ).tag(config=True)
+
+    focal_length_choice = CaselessStrEnum(
+        ['nominal', 'effective'],
+        default_value='effective',
+        help='Which focal length to use when constructing the SubarrayDescription.',
     ).tag(config=True)
 
     def __init__(self, input_url=None, config=None, parent=None, **kwargs):
@@ -574,21 +572,39 @@ class MAGICEventSource(EventSource):
         # }
 
         # MAGIC telescope positions in m wrt. to the center of MAGIC simulations, from
-        # CORSIKA and reflector input card and recomputed (rotated) to be w.r.t. geographical North 
+        # CORSIKA and reflector input card and recomputed (rotated) to be w.r.t. geographical North
         MAGIC_TEL_POSITIONS = {
             1: [34.99, -24.02, 0.00] * u.m,
             2: [-34.99, 24.02, 0.00] * u.m
         }
 
+        if self.focal_length_choice == 'effective':
+            # Use the effective focal length that the coma aberration is corrected
+            focal_length = u.Quantity(17*1.0713, u.m)
+        else:
+            focal_length = u.Quantity(17, u.m)
+
+        OPTICS = OpticsDescription(
+            'MAGIC',
+            num_mirrors=1,
+            equivalent_focal_length=focal_length,
+            mirror_area=u.Quantity(239.0, u.m**2),
+            num_mirror_tiles=964,
+        )
+
         # camera info from MAGICCam.camgeom.fits.gz file
         camera_geom = load_camera_geometry()
 
         pulse_shape_lo_gain = np.array([0., 1., 2., 1., 0.])
         pulse_shape_hi_gain = np.array([1., 2., 3., 2., 1.])
         pulse_shape = np.vstack((pulse_shape_lo_gain, pulse_shape_hi_gain))
+        sampling_speed = u.Quantity(
+            self.files_[0]['RunHeaders']['MRawRunHeader.fSamplingFrequency'].array(library='np')[0]/1000,
+            u.GHz
+        )
         camera_readout = CameraReadout(
             camera_name='MAGICCam',
-            sampling_rate=u.Quantity(1.64, u.GHz),
+            sampling_rate=sampling_speed,
             reference_pulse_shape=pulse_shape,
             reference_pulse_sample_width=u.Quantity(0.5, u.ns)
         )
@@ -1328,6 +1344,9 @@ class MarsCalibratedRun:
             events_cut['cosmic_events'] = f'(MTriggerPattern.fPrescaled == {DATA_STEREO_TRIGGER_PATTERN})'
             events_cut['pedestal_events'] = f'(MTriggerPattern.fPrescaled == {PEDESTAL_TRIGGER_PATTERN})'
 
+        # read common information from RunHeaders
+        sampling_speed = self.uproot_file['RunHeaders']['MRawRunHeader.fSamplingFrequency'].array(library='np')[0]/1000. # GHz
+
         # Loop over the event types:
         event_types = events_cut.keys()
 
@@ -1349,6 +1368,7 @@ class MarsCalibratedRun:
             # between 0 and 1039 are extracted, since the other part of pixels has only zeros):
             calib_data[event_type]['image'] = np.array(common_info['MCerPhotEvt.fPixels.fPhot'].tolist())[:, :self.n_cam_pixels]
             calib_data[event_type]['peak_time'] = np.array(common_info['MArrivalTime.fData'].tolist())[:, :self.n_cam_pixels]
+            calib_data[event_type]['peak_time']/=sampling_speed # [ns]
 
             if self.is_mc:
 
