@@ -233,6 +233,23 @@ def test_geom(dataset):
         assert source.subarray.tels[2].camera.geometry.pix_x.size == 1039
 
 
+@pytest.mark.parametrize('dataset', test_calibrated_all)
+def test_focal_length_choice(dataset):
+    from astropy import units as u
+    from ctapipe_io_magic import MAGICEventSource
+
+    with MAGICEventSource(input_url=dataset, process_run=False, focal_length_choice='nominal') as source:
+        assert source.subarray.tel[1].optics.equivalent_focal_length == u.Quantity(17, u.m)
+        assert source.subarray.tel[2].optics.equivalent_focal_length == u.Quantity(17, u.m)
+        assert source.subarray.tel[1].camera.geometry.frame.focal_length == u.Quantity(17, u.m)
+        assert source.subarray.tel[2].camera.geometry.frame.focal_length == u.Quantity(17, u.m)
+
+    with MAGICEventSource(input_url=dataset, process_run=False, focal_length_choice='effective') as source:
+        assert source.subarray.tel[1].optics.equivalent_focal_length == u.Quantity(17*1.0713, u.m)
+        assert source.subarray.tel[2].optics.equivalent_focal_length == u.Quantity(17*1.0713, u.m)
+        assert source.subarray.tel[1].camera.geometry.frame.focal_length == u.Quantity(17*1.0713, u.m)
+        assert source.subarray.tel[2].camera.geometry.frame.focal_length == u.Quantity(17*1.0713, u.m)
+
 # def test_eventseeker():
 #    dataset = get_dataset_path("20131004_M1_05029747.003_Y_MagicCrab-W0.40+035.root")
 #
